package com.sun.xml.internal.bind.api;

import java.io.InputStream;
import javax.xml.transform.Source;
import com.sun.istack.internal.Nullable;
import javax.xml.bind.attachment.AttachmentUnmarshaller;
import javax.xml.stream.XMLStreamReader;
import javax.xml.bind.Unmarshaller;
import javax.xml.transform.Result;
import org.xml.sax.ContentHandler;
import org.w3c.dom.Node;
import javax.xml.namespace.NamespaceContext;
import java.io.OutputStream;
import com.sun.xml.internal.bind.v2.runtime.BridgeContextImpl;
import javax.xml.bind.Marshaller;
import javax.xml.bind.attachment.AttachmentMarshaller;
import javax.xml.bind.JAXBException;
import javax.xml.stream.XMLStreamWriter;
import com.sun.istack.internal.NotNull;
import com.sun.xml.internal.bind.v2.runtime.JAXBContextImpl;

public abstract class Bridge<T>
{
    protected final JAXBContextImpl context;
    
    protected Bridge(JAXBContextImpl context) {
        this.context = context;
    }
    
    @NotNull
    public JAXBRIContext getContext() {
        return this.context;
    }
    
    public final void marshal(T object, XMLStreamWriter output) throws JAXBException {
        this.marshal(object, output, null);
    }
    
    public final void marshal(T object, XMLStreamWriter output, AttachmentMarshaller am) throws JAXBException {
        Marshaller m = (Marshaller)this.context.marshallerPool.take();
        m.setAttachmentMarshaller(am);
        this.marshal(m, object, output);
        m.setAttachmentMarshaller(null);
        this.context.marshallerPool.recycle(m);
    }
    
    public final void marshal(@NotNull BridgeContext context, T object, XMLStreamWriter output) throws JAXBException {
        this.marshal(((BridgeContextImpl)context).marshaller, object, output);
    }
    
    public abstract void marshal(@NotNull Marshaller p0, T p1, XMLStreamWriter p2) throws JAXBException;
    
    public void marshal(T object, OutputStream output, NamespaceContext nsContext) throws JAXBException {
        this.marshal(object, output, nsContext, null);
    }
    
    public void marshal(T object, OutputStream output, NamespaceContext nsContext, AttachmentMarshaller am) throws JAXBException {
        Marshaller m = (Marshaller)this.context.marshallerPool.take();
        m.setAttachmentMarshaller(am);
        this.marshal(m, object, output, nsContext);
        m.setAttachmentMarshaller(null);
        this.context.marshallerPool.recycle(m);
    }
    
    public final void marshal(@NotNull BridgeContext context, T object, OutputStream output, NamespaceContext nsContext) throws JAXBException {
        this.marshal(((BridgeContextImpl)context).marshaller, object, output, nsContext);
    }
    
    public abstract void marshal(@NotNull Marshaller p0, T p1, OutputStream p2, NamespaceContext p3) throws JAXBException;
    
    public final void marshal(T object, Node output) throws JAXBException {
        Marshaller m = (Marshaller)this.context.marshallerPool.take();
        this.marshal(m, object, output);
        this.context.marshallerPool.recycle(m);
    }
    
    public final void marshal(@NotNull BridgeContext context, T object, Node output) throws JAXBException {
        this.marshal(((BridgeContextImpl)context).marshaller, object, output);
    }
    
    public abstract void marshal(@NotNull Marshaller p0, T p1, Node p2) throws JAXBException;
    
    public final void marshal(T object, ContentHandler contentHandler) throws JAXBException {
        this.marshal(object, contentHandler, null);
    }
    
    public final void marshal(T object, ContentHandler contentHandler, AttachmentMarshaller am) throws JAXBException {
        Marshaller m = (Marshaller)this.context.marshallerPool.take();
        m.setAttachmentMarshaller(am);
        this.marshal(m, object, contentHandler);
        m.setAttachmentMarshaller(null);
        this.context.marshallerPool.recycle(m);
    }
    
    public final void marshal(@NotNull BridgeContext context, T object, ContentHandler contentHandler) throws JAXBException {
        this.marshal(((BridgeContextImpl)context).marshaller, object, contentHandler);
    }
    
    public abstract void marshal(@NotNull Marshaller p0, T p1, ContentHandler p2) throws JAXBException;
    
    public final void marshal(T object, Result result) throws JAXBException {
        Marshaller m = (Marshaller)this.context.marshallerPool.take();
        this.marshal(m, object, result);
        this.context.marshallerPool.recycle(m);
    }
    
    public final void marshal(@NotNull BridgeContext context, T object, Result result) throws JAXBException {
        this.marshal(((BridgeContextImpl)context).marshaller, object, result);
    }
    
    public abstract void marshal(@NotNull Marshaller p0, T p1, Result p2) throws JAXBException;
    
    private T exit(T r, Unmarshaller u) {
        u.setAttachmentUnmarshaller(null);
        this.context.unmarshallerPool.recycle(u);
        return r;
    }
    
    @NotNull
    public final T unmarshal(@NotNull XMLStreamReader in) throws JAXBException {
        return this.unmarshal(in, null);
    }
    
    @NotNull
    public final T unmarshal(@NotNull XMLStreamReader in, @Nullable AttachmentUnmarshaller au) throws JAXBException {
        Unmarshaller u = (Unmarshaller)this.context.unmarshallerPool.take();
        u.setAttachmentUnmarshaller(au);
        return this.exit(this.unmarshal(u, in), u);
    }
    
    @NotNull
    public final T unmarshal(@NotNull BridgeContext context, @NotNull XMLStreamReader in) throws JAXBException {
        return this.unmarshal(((BridgeContextImpl)context).unmarshaller, in);
    }
    
    @NotNull
    public abstract T unmarshal(@NotNull Unmarshaller p0, @NotNull XMLStreamReader p1) throws JAXBException;
    
    @NotNull
    public final T unmarshal(@NotNull Source in) throws JAXBException {
        return this.unmarshal(in, null);
    }
    
    @NotNull
    public final T unmarshal(@NotNull Source in, @Nullable AttachmentUnmarshaller au) throws JAXBException {
        Unmarshaller u = (Unmarshaller)this.context.unmarshallerPool.take();
        u.setAttachmentUnmarshaller(au);
        return this.exit(this.unmarshal(u, in), u);
    }
    
    @NotNull
    public final T unmarshal(@NotNull BridgeContext context, @NotNull Source in) throws JAXBException {
        return this.unmarshal(((BridgeContextImpl)context).unmarshaller, in);
    }
    
    @NotNull
    public abstract T unmarshal(@NotNull Unmarshaller p0, @NotNull Source p1) throws JAXBException;
    
    @NotNull
    public final T unmarshal(@NotNull InputStream in) throws JAXBException {
        Unmarshaller u = (Unmarshaller)this.context.unmarshallerPool.take();
        return this.exit(this.unmarshal(u, in), u);
    }
    
    @NotNull
    public final T unmarshal(@NotNull BridgeContext context, @NotNull InputStream in) throws JAXBException {
        return this.unmarshal(((BridgeContextImpl)context).unmarshaller, in);
    }
    
    @NotNull
    public abstract T unmarshal(@NotNull Unmarshaller p0, @NotNull InputStream p1) throws JAXBException;
    
    @NotNull
    public final T unmarshal(@NotNull Node n) throws JAXBException {
        return this.unmarshal(n, null);
    }
    
    @NotNull
    public final T unmarshal(@NotNull Node n, @Nullable AttachmentUnmarshaller au) throws JAXBException {
        Unmarshaller u = (Unmarshaller)this.context.unmarshallerPool.take();
        u.setAttachmentUnmarshaller(au);
        return this.exit(this.unmarshal(u, n), u);
    }
    
    @NotNull
    public final T unmarshal(@NotNull BridgeContext context, @NotNull Node n) throws JAXBException {
        return this.unmarshal(((BridgeContextImpl)context).unmarshaller, n);
    }
    
    @NotNull
    public abstract T unmarshal(@NotNull Unmarshaller p0, @NotNull Node p1) throws JAXBException;
    
    public abstract TypeReference getTypeReference();
}
